import { Envelope } from '@sentry/core';
import { RawEventContext } from '../../integration';
import { Sdk, SentryErrorEvent, SentryEvent, SentryProcessedProfile, SentryProfileV1Event, SentryTransactionEvent, Trace } from '../types';

type OnlineSubscription = ['online', (status: boolean) => void];
type EventSubscription = ['event', (event: SentryEvent) => void];
type TraceSubscription = ['trace', (trace: Trace) => void];
type Subscription = OnlineSubscription | EventSubscription | TraceSubscription;
export type SentryProfileWithTraceMeta = SentryProcessedProfile & {
    timestamp: number;
    active_thread_id: string;
};
declare class SentryDataCache {
    protected events: SentryEvent[];
    protected eventIds: Set<string>;
    protected sdks: Sdk[];
    protected traces: Trace[];
    protected tracesById: Map<string, Trace>;
    protected profilesByTraceId: Map<string, SentryProfileWithTraceMeta>;
    protected localTraceIds: Set<string>;
    protected envelopes: {
        envelope: Envelope;
        rawEnvelope: RawEventContext;
    }[];
    protected subscribers: Map<string, Subscription>;
    protected contextLinesProvider: string;
    constructor(initial?: (SentryEvent & {
        event_id?: string;
    })[]);
    setSidecarUrl(url: string): void;
    inferSdkFromEvent(event: SentryEvent): Sdk;
    pushEnvelope({ envelope, rawEnvelope }: {
        envelope: Envelope;
        rawEnvelope: RawEventContext;
    }): number;
    pushEvent(event: SentryEvent & {
        event_id?: string;
    }): Promise<void>;
    getEvents(): SentryEvent[];
    getTraces(): Trace[];
    getSdks(): Sdk[];
    getEnvelopes(): {
        envelope: Envelope;
        rawEnvelope: RawEventContext;
    }[];
    getEventById(id: string): SentryEvent | undefined;
    getTraceById(id: string): Trace | undefined;
    getProfileByTraceId(id: string): SentryProfileWithTraceMeta | undefined;
    getEventsByTrace(traceId: string, spanId?: string | null): SentryEvent[];
    resetData(): void;
    subscribe(...args: Subscription): () => void;
    /**
     * Mark a traceId as being seen in the local session.
     *
     * @param traceId
     */
    trackLocalTrace(traceId: string): void;
    /**
     * Determine if a traceId was seen in the local session.
     *
     * A result of `null` means "unknown", which implies there is no known
     * information about any session-initiated traces.
     */
    isTraceLocal(traceId: string): boolean | null;
    /**
     * Reverses the stack trace and tries to fill missing context lines
     * @param errorEvent
     * @returns
     */
    processStacktrace(errorEvent: SentryErrorEvent): Promise<void[]>;
}
declare const _default: SentryDataCache;
export default _default;
export declare function isErrorEvent(event: SentryEvent): event is SentryErrorEvent;
export declare function isProfileEvent(event: SentryEvent): event is SentryProfileV1Event;
export declare function isTraceEvent(event: SentryEvent): event is SentryTransactionEvent;
